Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1081)

Unified Diff: ui/views/animation/ink_drop_animation_controller_impl.h

Issue 1937103003: Rename of InkDropAnimation classes to InkDropRipple. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Removed test_ink_drop_animation_observer.h from views.gyp and doc update. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/animation/ink_drop_animation_controller_impl.h
diff --git a/ui/views/animation/ink_drop_animation_controller_impl.h b/ui/views/animation/ink_drop_animation_controller_impl.h
index c47a0a2f4baea84a0d6ec6e070cf58254014a9c3..aab859555f1a08692d98e08cc444037a4e1b401e 100644
--- a/ui/views/animation/ink_drop_animation_controller_impl.h
+++ b/ui/views/animation/ink_drop_animation_controller_impl.h
@@ -11,8 +11,8 @@
#include "ui/gfx/geometry/rect.h"
#include "ui/gfx/geometry/size.h"
#include "ui/views/animation/ink_drop_animation_controller.h"
-#include "ui/views/animation/ink_drop_animation_observer.h"
#include "ui/views/animation/ink_drop_hover_observer.h"
+#include "ui/views/animation/ink_drop_ripple_observer.h"
#include "ui/views/views_export.h"
namespace base {
@@ -24,7 +24,7 @@ namespace test {
class InkDropAnimationControllerImplTestApi;
} // namespace test
-class InkDropAnimation;
+class InkDropRipple;
class InkDropHost;
class InkDropHover;
class InkDropAnimationControllerFactoryTest;
@@ -32,7 +32,7 @@ class InkDropAnimationControllerFactoryTest;
// A functional implementation of an InkDropAnimationController.
class VIEWS_EXPORT InkDropAnimationControllerImpl
: public InkDropAnimationController,
- public InkDropAnimationObserver,
+ public InkDropRippleObserver,
public InkDropHoverObserver {
public:
// Constructs an ink drop controller that will attach the ink drop to the
@@ -50,16 +50,16 @@ class VIEWS_EXPORT InkDropAnimationControllerImpl
private:
friend class test::InkDropAnimationControllerImplTestApi;
// Destroys |ink_drop_animation_| if it's targeted to the HIDDEN state.
void DestroyHiddenTargetedAnimations();
- // Creates a new InkDropAnimation and sets it to |ink_drop_animation_|. If
- // |ink_drop_animation_| wasn't null then it will be destroyed using
- // DestroyInkDropAnimation().
- void CreateInkDropAnimation();
+ // Creates a new InkDropRipple and sets it to |ink_drop_ripple_|. If
+ // |ink_drop_ripple_| wasn't null then it will be destroyed using
+ // DestroyInkDropRipple().
+ void CreateInkDropRipple();
- // Destroys the current |ink_drop_animation_|.
- void DestroyInkDropAnimation();
+ // Destroys the current |ink_drop_ripple_|.
+ void DestroyInkDropRipple();
// Creates a new InkDropHover and sets it to |hover_|. If |hover_| wasn't null
// then it will be destroyed using DestroyInkDropHover().
@@ -80,7 +80,7 @@ class VIEWS_EXPORT InkDropAnimationControllerImpl
// is visible.
bool IsHoverFadingInOrVisible() const;
- // views::InkDropAnimationObserver:
+ // views::InkDropRippleObserver:
void AnimationStarted(InkDropState ink_drop_state) override;
void AnimationEnded(InkDropState ink_drop_state,
InkDropAnimationEndedReason reason) override;
@@ -98,23 +98,23 @@ class VIEWS_EXPORT InkDropAnimationControllerImpl
base::TimeDelta animation_duration,
bool explode);
- // Starts the |hover_after_animation_timer_| timer. This will stop the current
- // |hover_after_animation_timer_| instance if it exists.
- void StartHoverAfterAnimationTimer();
+ // Starts the |hover_after_ripple_timer_| timer. This will stop the current
+ // |hover_after_ripple_timer_| instance if it exists.
+ void StartHoverAfterRippleTimer();
- // Stops and destroys the current |hover_after_animation_timer_| instance.
- void StopHoverAfterAnimationTimer();
+ // Stops and destroys the current |hover_after_ripple_timer_| instance.
+ void StopHoverAfterRippleTimer();
- // Callback for when the |hover_after_animation_timer_| fires.
- void HoverAfterAnimationTimerFired();
+ // Callback for when the |hover_after_ripple_timer_| fires.
+ void HoverAfterRippleTimerFired();
// The host of the ink drop. Used to poll for information such as whether the
// hover should be shown or not.
InkDropHost* ink_drop_host_;
// The root Layer that parents the InkDropAnimation layers and the
// InkDropHover layers. The |root_layer_| is the one that is added and removed
// from the InkDropHost.
std::unique_ptr<ui::Layer> root_layer_;
// True when the |root_layer_| has been added to the |ink_drop_host_|.
@@ -127,12 +127,12 @@ class VIEWS_EXPORT InkDropAnimationControllerImpl
// SetHovered() function.
bool is_hovered_;
- // The current InkDropAnimation. Created on demand using
- // CreateInkDropAnimation().
- std::unique_ptr<InkDropAnimation> ink_drop_animation_;
+ // The current InkDropRipple. Created on demand using CreateInkDropRipple().
+ std::unique_ptr<InkDropRipple> ink_drop_ripple_;
- // The timer used to delay the hover fade in after an ink drop animation.
- std::unique_ptr<base::Timer> hover_after_animation_timer_;
+ // The timer used to delay the hover fade in after an ink drop ripple
+ // animation.
+ std::unique_ptr<base::Timer> hover_after_ripple_timer_;
DISALLOW_COPY_AND_ASSIGN(InkDropAnimationControllerImpl);
};
« no previous file with comments | « ui/views/animation/ink_drop_animation_controller.h ('k') | ui/views/animation/ink_drop_animation_controller_impl.cc » ('j') | no next file with comments »
@@ -50,16 +50,16 @@ class VIEWS_EXPORT InkDropAnimationControllerImpl
private:
friend class test::InkDropAnimationControllerImplTestApi;
- // Destroys |ink_drop_animation_| if it's targeted to the HIDDEN state.
+ // Destroys |ink_drop_ripple_| if it's targeted to the HIDDEN state.
void DestroyHiddenTargetedAnimations();
@@ -98,23 +98,23 @@ class VIEWS_EXPORT InkDropAnimationControllerImpl
// hover should be shown or not.
InkDropHost* ink_drop_host_;
- // The root Layer that parents the InkDropAnimation layers and the
- // InkDropHover layers. The |root_layer_| is the one that is added and removed
- // from the InkDropHost.
+ // The root Layer that parents the InkDropRipple layers and the InkDropHover
+ // layers. The |root_layer_| is the one that is added and removed from the
+ // InkDropHost.
std::unique_ptr<ui::Layer> root_layer_;
// True when the |root_layer_| has been added to the |ink_drop_host_|.

Powered by Google App Engine
This is Rietveld 408576698